examcosts: Cost of exam

Description Usage Arguments Value Examples

View source: R/examcosts.R

Description

Can be used to computed the normed costs as defined in the paper, S*F(t) + t, where S is the costs quotient, and F(t) is the probability if incorrect failing in an exam with duration t, mean mu, standard deviaton sigma1 at t=1, reliability rho1 at t=1, and cutoff a.

Usage

1
examcosts(t,S,a,mu,sigma1,rho1)

Arguments

t

duration

S

costs quotient

a

cutoff

mu

mean

sigma1

original SD

rho1

original reliability

Value

Costs of exam

Examples

1
examcosts(1, 20, 5.5,5.8,2, 0.5)

JulesEllis/exdur documentation built on Oct. 30, 2019, 8:06 p.m.