Description Usage Arguments Value Examples
Can be used to computed the normed costs as defined in the paper, S*F(t) + t, where S is the costs quotient, and F(t) is the probability if incorrect failing in an exam with duration t, mean mu, standard deviaton sigma1 at t=1, reliability rho1 at t=1, and cutoff a.
1 |
t |
duration |
S |
costs quotient |
a |
cutoff |
mu |
mean |
sigma1 |
original SD |
rho1 |
original reliability |
Costs of exam
1 | examcosts(1, 20, 5.5,5.8,2, 0.5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.